<?php
namespace Teknisa\PED\Modules\Expedicao\Controllers;

use Teknisa\PED\Controllers\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\ParameterBag;
use \Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use \Doctrine\ORM\EntityManager;
use \Teknisa\Libs\Util\DateUtil;

class Exp01800CancelamentoController extends TeknisaCrud {

    protected $dataSourceName = 'cancelamento';
    protected $newCode;
    protected $environment;
    protected $entityManager;

    public function __construct($crudService, ParameterBag $parameterBag, $newCode, $environment, $entityManager, $cancelamentoService) {
        parent::__construct($crudService, $parameterBag);
        $this->newCode = $newCode;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->cancelamentoService = $cancelamentoService;
    }

    public function cancelarExpedicao($request, $response) {

        $rows = $request->getDataSet()->getRows();

        try {
            $this->cancelamentoService->cancelarNota($rows);
            $this->getErroCancelamento($request, $response, $rows);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }

    }
    


    public function busca($request, $response) {
        
        $conditionsResquest = $request->getFilterCriteria()->getConditions();
        
        $newConditions = array();
        
        foreach($conditionsResquest as $condition) {
            
            if($condition['columnName'] == 'DTENTRSAID') {
                
                $p_dtinicial = array(
                    
                        'columnName' => 'P_DTINICIAL',
                        'value' => $condition['value'][0],
                        'operator' => '='
                    
                    );
                    
                $newConditions[] = $p_dtinicial;
                    
                $p_dtfinal = array(
                    
                        'columnName' => 'P_DTFINAL',
                        'value' => $condition['value'][1],
                        'operator' => '='
                        
                    );
                
                $newConditions[] = $p_dtfinal;
                
            }
            
             if($condition['columnName'] == 'CDFILIAL') {
                
                $p_cdfilial = array(
                    
                        'columnName' => 'P_CDFILIAL',
                        'value' => str_replace('%','',$condition['value']),
                        'operator' => '='
                    
                    );
                    
                $newConditions[] = $p_cdfilial;
                
            }

            if($condition['columnName'] == 'NREXPEDICAO' || $condition['columnName'] == 'CDROTATRANS') {

                $p_stringValue = ',';

                foreach($condition['value'] as $value) {

                    $p_stringValue .= $value.',';

                }

                $p_conditionArray = array(
                    
                    'columnName' => 'P_'.$condition['columnName'],
                    'value' =>  $p_stringValue,
                    'operator' => '='
                
                );

                $newConditions[] = $p_conditionArray;

            }
            
        }
        
        $this->parameterBagColumns = array('P_CDFILIAL','P_DTINICIAL','P_DTFINAL', 'P_NREXPEDICAO', 'P_CDROTATRANS');
        
        $filterCriteria = new FilterCriteria('cancelamento',$newConditions);
        
        $requestFiltro = new DTO\Request\Filter($filterCriteria, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
            
        parent::find($requestFiltro,$response);
        
    }
    
    
    public function getErroCancelamento($request, $response, $rows) {
        
        $retorno = array();
        foreach($rows as $row){
            $nrlanctonf = $row['NRLANCTONF'];

            $filter = array(
                array(
                    "columnName" => "NRLANCTONF",
                    "operator" => "=",
                    "value" => $nrlanctonf
                )
            );
            
            $erroCancelamento = new DTO\Response();
            $filterCriteria = new FilterCriteria('travacancelaexpedicao', $filter);
            $erros = $this->crudService->find($erroCancelamento, $filterCriteria);
            
            $getErroCancelamento = $erroCancelamento->getDataSets()[0]->getRows();
            
              
            if(isset($getErroCancelamento[0])){
                if($getErroCancelamento[0]['IDERRO'] == "TRAVAESTNFRELAC"){
                    $msg = ('Operação Bloqueada! O estoque da nota relacionada ficará irregular.');
                };
                if($getErroCancelamento[0]['IDERRO'] == "TRAVASTATUSNFRELAC"){
                    $msg = ('Operação Bloqueada! A situação da nota relacionada não permite o cancelamento.');
                };
                if($getErroCancelamento[0]['IDERRO'] == "TRAVAESTNF"){
                    $msg = ('Operação Bloqueada! O estoque da nota ficará irregular.');
                };
                if($getErroCancelamento[0]['IDERRO'] == "TRAVASTATUSNF"){
                    $msg = ('Operação Bloqueada! A situação da nota não permite o cancelamento.');
                }
            }else{
                $msg = ('Nota Fiscal Cancelada!');
            }
            
            $erro = array("NRLANCTONF" => $nrlanctonf ,"IDERRO" => $msg);
            array_push($retorno, $erro);
        }
        $returno = new DataSet ("data", $retorno);
        $response -> addDataSet($returno);
    }
    
    
}

